@@ -30,6 +30,7 @@ pub struct Deserializer<R> {
     #[cfg(feature = "unbounded_depth")]
     disable_recursion_limit: bool,
     ignore_trailing_commas: bool,
+    allow_comments: bool,
 }
 
 impl<'de, R> Deserializer<R>
@@ -54,6 +55,7 @@ where
             #[cfg(feature = "unbounded_depth")]
             disable_recursion_limit: false,
             ignore_trailing_commas: true,
+            allow_comments: true,
         }
     }
 }
@@ -76,13 +78,13 @@ where
 impl<'a> Deserializer<read::SliceRead<'a>> {
     /// Creates a JSON deserializer from a `&[u8]`.
     pub fn from_slice(bytes: &'a [u8]) -> Self {
-        Deserializer::new(read::SliceRead::new(bytes, false))
+        Deserializer::new(read::SliceRead::new(bytes, false, false, false, false))
     }
 
     /// Creates a JSON deserializer from a `&[u8]`,
-    /// replacing invalid characters.
-    pub fn from_slice_replacing_invalid_characters(bytes: &'a [u8]) -> Self {
-        Deserializer::new(read::SliceRead::new(bytes, true))
+    /// providing some flexibility for some non-standard JSON options.
+    pub fn from_slice_with_options(bytes: &'a [u8], replace_invalid_characters: bool, allow_control_characters_in_string: bool, allow_v_escapes: bool, allow_x_escapes: bool) -> Self {
+        Deserializer::new(read::SliceRead::new(bytes, replace_invalid_characters, allow_control_characters_in_string, allow_v_escapes, allow_x_escapes))
     }
 }
 
@@ -231,6 +233,11 @@ impl<'de, R: Read<'de>> Deserializer<R> {
         self.ignore_trailing_commas = ignore;
     }
 
+    /// Whether to allow comments.
+    pub fn set_allow_comments(&mut self, allow: bool) {
+        self.allow_comments = allow;
+    }
+
     fn peek(&mut self) -> Result<Option<u8>> {
         self.read.peek()
     }
@@ -274,7 +281,7 @@ impl<'de, R: Read<'de>> Deserializer<R> {
                 Some(b' ') | Some(b'\n') | Some(b'\t') | Some(b'\r') => {
                     self.eat_char();
                 }
-                Some(b'/') => {
+                Some(b'/') if self.allow_comments => {
                     self.eat_char();
                     match tri!(self.peek()) {
                         Some(b'/') => {
@@ -2684,7 +2691,16 @@ pub fn from_slice<'a, T>(v: &'a [u8]) -> Result<T>
 where
     T: de::Deserialize<'a>,
 {
-    from_trait(read::SliceRead::new(v, false))
+    from_trait(read::SliceRead::new(v, false, false, false, false))
+}
+
+/// Like `from_slice`, but switches on all our quirks modes. For tests.
+/// (Isn't marked `#[cfg(test)]` because we need this in UI tests.)
+pub fn from_str_lenient<'a, T>(s: &'a str) -> Result<T>
+where
+    T: de::Deserialize<'a>,
+{
+    from_trait(read::SliceRead::new(s.as_bytes(), true, true, true, true))
 }
 
 /// Deserialize an instance of type `T` from a string of JSON text.
