@@ -101,6 +101,12 @@ pub trait Read<'de>: private::Sealed {
     /// Whether we should replace invalid unicode characters with \u{fffd}.
     fn replace_invalid_unicode(&self) -> bool;
 
+    /// Allow \v escapes
+    fn allow_v_escapes(&self) -> bool;
+
+    /// Allow \x escapes
+    fn allow_x_escapes(&self) -> bool;
+
     /// Whether StreamDeserializer::next needs to check the failed flag. True
     /// for IoRead, false for StrRead and SliceRead which can track failure by
     /// truncating their input slice to avoid the extra check on every next
@@ -315,6 +321,9 @@ pub struct SliceRead<'a> {
     /// Index of the *next* byte that will be returned by next() or peek().
     index: usize,
     replace_invalid_characters: bool,
+    allow_control_characters_in_string: bool,
+    allow_x_escapes: bool,
+    allow_v_escapes: bool,
     #[cfg(feature = "raw_value")]
     raw_buffering_start_index: usize,
 }
@@ -402,6 +411,14 @@ where
         false
     }
 
+    fn allow_x_escapes(&self) -> bool {
+        false
+    }
+
+    fn allow_v_escapes(&self) -> bool {
+        false
+    }
+
     #[inline]
     fn next(&mut self) -> Result<Option<u8>> {
         match self.ch.take() {
@@ -559,16 +576,23 @@ where
 
 impl<'a> SliceRead<'a> {
     /// Create a JSON input source to read from a slice of bytes.
-    pub fn new(slice: &'a [u8], replace_invalid_characters: bool) -> Self {
+    pub fn new(slice: &'a [u8], replace_invalid_characters: bool, allow_control_characters_in_string: bool, allow_v_escapes: bool, allow_x_escapes: bool) -> Self {
         SliceRead {
             slice,
             index: 0,
             replace_invalid_characters,
+            allow_control_characters_in_string,
+            allow_v_escapes,
+            allow_x_escapes,
             #[cfg(feature = "raw_value")]
             raw_buffering_start_index: 0,
         }
     }
 
+    fn escapes(&self) -> [bool;256] {
+        get_escapes(self.allow_control_characters_in_string)
+    }
+
     fn position_of_index(&self, i: usize) -> Position {
         let mut position = Position { line: 1, column: 0 };
         for ch in &self.slice[..i] {
@@ -602,7 +626,7 @@ impl<'a> SliceRead<'a> {
         let mut start = self.index;
 
         loop {
-            while self.index < self.slice.len() && !ESCAPE[self.slice[self.index] as usize] {
+            while self.index < self.slice.len() && !self.escapes()[self.slice[self.index] as usize] {
                 self.index += 1;
             }
             if self.index == self.slice.len() {
@@ -648,6 +672,14 @@ impl<'a> Read<'a> for SliceRead<'a> {
         self.replace_invalid_characters
     }
 
+    fn allow_x_escapes(&self) -> bool {
+        self.allow_x_escapes
+    }
+
+    fn allow_v_escapes(&self) -> bool {
+        self.allow_v_escapes
+    }
+
     #[inline]
     fn next(&mut self) -> Result<Option<u8>> {
         // `Ok(self.slice.get(self.index).map(|ch| { self.index += 1; *ch }))`
@@ -708,7 +740,7 @@ impl<'a> Read<'a> for SliceRead<'a> {
 
     fn ignore_str(&mut self) -> Result<()> {
         loop {
-            while self.index < self.slice.len() && !ESCAPE[self.slice[self.index] as usize] {
+            while self.index < self.slice.len() && !self.escapes()[self.slice[self.index] as usize] {
                 self.index += 1;
             }
             if self.index == self.slice.len() {
@@ -785,7 +817,7 @@ impl<'a> StrRead<'a> {
     /// Create a JSON input source to read from a UTF-8 string.
     pub fn new(s: &'a str) -> Self {
         StrRead {
-            delegate: SliceRead::new(s.as_bytes(), false),
+            delegate: SliceRead::new(s.as_bytes(), false, false, false, false),
             #[cfg(feature = "raw_value")]
             data: s,
         }
@@ -799,6 +831,14 @@ impl<'a> Read<'a> for StrRead<'a> {
         false
     }
 
+    fn allow_x_escapes(&self) -> bool {
+        false
+    }
+
+    fn allow_v_escapes(&self) -> bool {
+        false
+    }
+
     #[inline]
     fn next(&mut self) -> Result<Option<u8>> {
         self.delegate.next()
@@ -944,6 +984,14 @@ where
     fn replace_invalid_unicode(&self) -> bool {
         R::replace_invalid_unicode(self)
     }
+
+    fn allow_x_escapes(&self) -> bool {
+        R::allow_x_escapes(self)
+    }
+
+    fn allow_v_escapes(&self) -> bool {
+        R::allow_v_escapes(self)
+    }
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -953,12 +1001,13 @@ pub trait Fused: private::Sealed {}
 impl<'a> Fused for SliceRead<'a> {}
 impl<'a> Fused for StrRead<'a> {}
 
-const ALLOW_CONTROL_CHARACTERS_IN_STRING: bool = false;
+const ESCAPE: [bool; 256] = get_escapes(false);
 
 // Lookup table of bytes that must be escaped. A value of true at index i means
 // that byte i requires an escape sequence in the input.
-static ESCAPE: [bool; 256] = {
-    const CT: bool = ALLOW_CONTROL_CHARACTERS_IN_STRING; // control character \x00..=\x1F
+const fn get_escapes(allow_control_characters_in_string: bool) -> [bool; 256] {
+    #[allow(non_snake_case)]
+    let CT: bool = !allow_control_characters_in_string; // control character \x00..=\x1F
     const QU: bool = true; // quote \x22
     const BS: bool = true; // backslash \x5C
     const __: bool = false; // allow unescaped
@@ -981,7 +1030,7 @@ static ESCAPE: [bool; 256] = {
         __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, // E
         __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, // F
     ]
-};
+}
 
 fn next_or_eof<'de, R>(read: &mut R) -> Result<u8>
 where
@@ -1045,8 +1094,8 @@ fn parse_escape_or_fail<'de, R: Read<'de>>(read: &mut R, scratch: &mut Vec<u8>)
         b'n' => scratch.push(b'\n'),
         b'r' => scratch.push(b'\r'),
         b't' => scratch.push(b'\t'),
-        b'v' => scratch.push(b'\x0b'),
-        b'x' => {
+        b'v' if read.allow_v_escapes() => scratch.push(b'\x0b'),
+        b'x' if read.allow_x_escapes() => {
             let c: u32 = tri!(read.decode_hex_escape(2)).into();
             let c = match char::from_u32(c) {
                 Some(c) => c,
